class ShowNewFeature {
  constructor(config) {
    this.tooltipData = [];
    this.currentIndex = 0;
    this.config = config || {};
    this.tooltip = document.querySelector(
      this.config.tooltipSelector || "#tooltip"
    );
    this.tooltipContent = document.querySelector(
      this.config.tooltipContentSelector || "#tooltipContent"
    );
    this.overlay = document.querySelector(
      this.config.overlaySelector || "#overlay"
    );
    this.nextButton = document.querySelector(
      this.config.nextButtonSelector || "#nextButton"
    );
    this.exitButton = document.createElement("button");
    this.exitButton.innerText = "Sair";
    this.exitButton.style.marginLeft = "10px";
    this.tooltip.appendChild(this.exitButton);

    if (this.nextButton) {
      this.nextButton.addEventListener("click", () => this.nextTooltip());
    } else {
      console.error("Next button element not found");
    }

    if (this.exitButton) {
      this.exitButton.addEventListener("click", () => this.exitTooltip());
    } else {
      console.error("Exit button element not found");
    }
  }

  init() {
    if (Notification.permission !== "granted") {
      Notification.requestPermission();
    }

    fetch(this.config.dataUrl || "features.json")
      .then((response) => response.json())
      .then((data) => {
        const currentUrl = window.location.href;
        const targetUrl = data.url;

        if (currentUrl !== targetUrl) {
          console.log("URL does not match. Tooltips will not be shown.");
          return;
        }

        const storedVersion = localStorage.getItem("tooltipVersion");
        const currentVersion = data.version;

        if (currentVersion !== storedVersion) {
          localStorage.removeItem("tooltipIndex");
          localStorage.removeItem("tooltipState");
          localStorage.setItem("tooltipVersion", currentVersion);

          if (Notification.permission === "granted") {
            const notification = new Notification(data.notificationTitle, {
              body: data.notificationBody,
              icon: data.notificationIcon,
            });

            notification.onclick = () => {
              window.open(targetUrl, "_blank");
              this.startTooltipSequence(data);
            };

            setTimeout(() => {
              this.startTooltipSequence(data);
            }, 6000);
          }
        } else {
          this.startTooltipSequence(data);
        }
      });
  }

  startTooltipSequence(data) {
    this.tooltipData = data.features;
    const tooltipState = localStorage.getItem("tooltipState");

    if (tooltipState === "completed" || tooltipState === "exited") {
      this.hideTooltip();
      return;
    }

    const seenIndex = localStorage.getItem("tooltipIndex");

    if (seenIndex === "completed" || seenIndex === "exited") {
      this.hideTooltip();
    } else {
      this.currentIndex = seenIndex ? parseInt(seenIndex, 10) : 0;
      if (this.currentIndex < this.tooltipData.length) {
        this.showTooltip(this.tooltipData[this.currentIndex]);
      } else {
        this.hideTooltip();
      }
    }
  }

  showTooltip(feature) {
    this.tooltipContent.innerHTML = `<h2>${feature.title}</h2><p>${feature.description}</p>`;
    this.tooltip.style.display = "block";
    this.overlay.style.display = "block";

    if (this.currentIndex > 0) {
      const previousFeature = this.tooltipData[this.currentIndex - 1];
      const previousElement = document.querySelector(
        `[data-feature="${previousFeature["data-feature"]}"]`
      );
      if (previousElement) {
        previousElement.style.zIndex = "";
        previousElement.style.backgroundColor = "";
        previousElement.style.position = "";
      }
    }

    const element = document.querySelector(
      `[data-feature="${feature["data-feature"]}"]`
    );

    if (element) {
      element.style.zIndex = "1000";
      element.style.backgroundColor = "white";
      element.style.position = "relative";

      const rect = element.getBoundingClientRect();
      let top = rect.top + window.scrollY - this.tooltip.offsetHeight - 10;
      let left = rect.left + window.scrollX;

      if (top < 0) {
        top = rect.bottom + window.scrollY + 10;
      }

      if (left + this.tooltip.offsetWidth > window.innerWidth) {
        left = window.innerWidth - this.tooltip.offsetWidth - 10;
      }

      if (left < 0) {
        left = 10;
      }

      this.tooltip.style.top = `${top}px`;
      this.tooltip.style.left = `${left}px`;
    }

    this.nextButton.innerText =
      this.currentIndex === this.tooltipData.length - 1
        ? "Concluir"
        : "Próximo";
  }

  nextTooltip() {
    this.currentIndex++;
    if (this.currentIndex < this.tooltipData.length) {
      const feature = this.tooltipData[this.currentIndex];
      this.showTooltip(feature);
      localStorage.setItem("tooltipIndex", this.currentIndex);
    } else {
      this.hideTooltip();
      localStorage.setItem("tooltipIndex", "completed");
      localStorage.setItem("tooltipState", "completed");
    }
  }

  exitTooltip() {
    this.hideTooltip();
    localStorage.setItem("tooltipState", "exited");
  }

  hideTooltip() {
    this.tooltip.style.display = "none";
    this.overlay.style.display = "none";

    this.tooltipData.forEach((feature) => {
      const element = document.querySelector(
        `[data-feature="${feature["data-feature"]}"]`
      );
      if (element) {
        element.style.zIndex = "";
        element.style.backgroundColor = "";
        element.style.position = "";
      }
    });
  }
}

module.exports = ShowNewFeature;
